<?php
/**
 * graftee functions and definitions
 *
 * @package graftee
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 320; /* pixels */
}

function graftee_switch_theme() {
	remove_theme_mod( 'background_color' );
	remove_theme_mod( 'header_backgroundcolor' );
	remove_theme_mod( 'header_textcolor' );
}

add_action( 'switch_theme', 'graftee_switch_theme' );

if ( ! function_exists( 'graftee_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function graftee_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on graftee, use a find and replace
	 * to change 'graftee' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'graftee', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'メニュー', 'graftee' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'graftee_custom_background_args', array(
		'default-color' => 'f3f3f3',
		'default-image' => '',
	) ) );

	// title
	add_theme_support( 'title-tag' );
}
endif; // graftee_setup
add_action( 'after_setup_theme', 'graftee_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function graftee_widgets_init() {
	register_sidebar( array(
		'name'		=> __( 'サイドバー', 'graftee' ),
		'id'		=> 'sidebar-1',
		'description'	=> '',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</div>',
		'before_title'	=> '<h2 class="widget-title">',
		'after_title'	=> '</h2>',
	) );
}

add_action( 'widgets_init', 'graftee_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function graftee_wp_enqueue_scripts() {
	wp_enqueue_style( 'graftee-style', get_stylesheet_uri() );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'graftee_wp_enqueue_scripts' );

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses graftee_header_style()
 * @uses graftee_admin_header_style()
 * @uses graftee_admin_header_image()
 */
function graftee_after_setup_theme() {
	$wp_head_callback = 'graftee_header_style';
	if ( file_exists( get_stylesheet_directory().'/customizer.php' ) ) {
		require_once( get_stylesheet_directory().'/customizer.php' );
		$wp_head_callback = str_replace( '-', '_', get_stylesheet() ).'_header_style';
	} else {
		require_once( 'customizer.php' );
		
	}


	add_theme_support( 'custom-header', apply_filters( 'graftee_custom_header_args', array(
		'default-image'          => '',
		'default-text-color'     => 'ffffff',
		'width'                  => 1000,
		'height'                 => 250,
		'flex-height'            => true,
		'wp-head-callback'       => $wp_head_callback,
		'admin-head-callback'    => 'graftee_admin_header_style',
		'admin-preview-callback' => 'graftee_admin_header_image',
	) ) );
}

add_action( 'after_setup_theme', 'graftee_after_setup_theme' );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function graftee_customize_register( $wp_customize ) {
	$wp_customize->add_setting( 'header_backgroundcolor', array(
		'default' => '#000000',
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_backgroundcolor', array(
		'settings' => 'header_backgroundcolor',
		'label' => __( 'ヘッダー背景色', 'graftee' ),
		'section' => 'colors',
	) ) );

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->get_setting( 'header_backgroundcolor' )->transport = 'postMessage';
	$wp_customize->get_setting( 'background_color' )->transport = 'postMessage';
}
add_action( 'customize_register', 'graftee_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function graftee_customize_preview_init() {
	$customizer_js_uri = get_stylesheet_directory().'/customizer.js';
	if ( file_exists( get_stylesheet_directory().'/customizer.js' ) ) {
		$customizer_js_uri = get_stylesheet_directory_uri().'/customizer.js';
	} else {
		$customizer_js_uri = get_template_directory_uri().'/customizer.js';
	}

	wp_enqueue_script(
		'graftee_customizer',
		$customizer_js_uri,
		array( 'jquery', 'customize-preview' ),
		'20141206'
	);
}

add_action( 'customize_preview_init', 'graftee_customize_preview_init' );

if ( ! function_exists( 'graftee_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 */
function graftee_paging_nav() {
	if ( is_singular() ) {
		return ;
	}

	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	global $wp_query, $paged;
	$big = 999999999;

	$pages = $wp_query -> max_num_pages;
	if ( empty( $paged ) ) $paged = 1;

	echo paginate_links( array(
		'base'      => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
		'format'    => '?paged=%#%',
		'current'   => max( 1, get_query_var( 'paged' ) ),
		'total'     => $wp_query -> max_num_pages,
		'mid_size'  => 3,
		'prev_text' => __( '前へ', 'graftee' ),
		'next_text' => __( '次へ', 'graftee' ),
		'type'      => 'list'
	) );
}
endif;

if ( ! function_exists( 'graftee_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function graftee_post_nav() {
	if ( !is_singular() ) {
		return ;
	}

	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<ul class="nav-links navigation post-navigation">
		<?php
			previous_post_link( '<li class="nav-previous">%link</li>', '%title' );
			next_post_link( '<li class="nav-next">%link</li>', '%title' );
		?>
	</ul>
	<?php
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function graftee_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'graftee_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'graftee_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so graftee_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so graftee_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in graftee_categorized_blog.
 */
function graftee_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'graftee_categories' );
}
add_action( 'edit_category', 'graftee_category_transient_flusher' );
add_action( 'save_post',     'graftee_category_transient_flusher' );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @param array $args Configuration arguments.
 * @return array
 */
function graftee_wp_page_menu_args() {
	$args['show_home'] = true;
	return $args;
}

add_filter( 'wp_page_menu_args', 'graftee_wp_page_menu_args' );

/**
 * Filters wp_title to print a neat <title> tag based on what is being viewed.
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 */
function graftee_wp_title( $title, $sep ) {
	if ( is_feed() ) {
		return $title;
	}

	global $page, $paged;

	if ( is_search() ) {
		$title = sprintf( __( '検索結果：%s', 'graftee' ), get_search_query() );
	}

	if ( trim( $title ) == '' ) {
		$title = get_bloginfo( 'name' );
	}

	// Add a page number if necessary:
	if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
		$title .= " $sep " . sprintf( __( '%sページ', 'graftee' ), max( $paged, $page ) );
	}

	return $title;
}
add_filter( 'wp_title', 'graftee_wp_title', 10, 2 );

/**
 * Sets the authordata global when viewing an author archive.
 *
 * This provides backwards compatibility with
 * http://core.trac.wordpress.org/changeset/25574
 *
 * It removes the need to call the_post() and rewind_posts() in an author
 * template to print information about the author.
 *
 * @global WP_Query $wp_query WordPress Query object.
 * @return void
 */
function graftee_wp(){
	global $wp_query;

	if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
		$GLOBALS['authordata'] = get_userdata( $wp_query->post->post_author );
	}
}

add_action( 'wp', 'graftee_wp' );

if ( file_exists( get_stylesheet_directory().'/editor-style.css' ) ) {
	add_editor_style( get_stylesheet_directory_uri().'/editor-style.css' );
} else {
	add_editor_style('editor-style.css' );
}

if ( ! function_exists( 'graftee_category_ancetitles' ) ) :
function graftee_category_ancetitles( $page ) {
	$cat = get_the_category();
	if ( count( $cat ) == 0 ) {
		return '';
	}

	$ancestors = array();

	$ancestors[] = '<li><a href="' . get_category_link($cat[0]->term_id) . '" itemprop="url">' . $cat[0]->cat_name . '</a></li>';
	$parent_cat_id = $cat[0]->parent;

	while ( $parent_cat_id != 0 ) {
		$cat = get_category( $parent_cat_id );
		$ancestors[] = '<li><a href="' . get_category_link($cat->term_id) . '" itemprop="url">' . $cat->cat_name . '</a></li>';
		$parent_cat_id = $cat->parent;
	}

	return join( '', array_reverse( $ancestors ) );
}
endif;

if ( ! function_exists( 'graftee_make_excerpt' ) ) :
function graftee_make_excerpt( $length = 100 ) {
	global $post;
	if ( post_password_required() ) {
		_e( 'このコンテンツはパスワードで保護されています。閲覧するには以下にパスワードを入力してください。', 'graftee' );
		return;
	}

	$excerpt = str_replace( array(' ', "\r\n", "\r", "\n"), ' ', strip_tags( $post->post_content ) );
	$excerpt = preg_replace( '/\[[^\]]*\]/', '', $excerpt );

	echo mb_substr( $excerpt, 0, $length );
}
endif;

function graftee_body_class( $classes ) {
	switch ( get_option( 'start_of_week' ) ) {
		case 0:
			$classes[] = 'start-of-week-sun';
			break;
		case 1:
			$classes[] = 'start-of-week-mon';
			break;
		case 2:
			$classes[] = 'start-of-week-tue';
			break;
		case 3:
			$classes[] = 'start-of-week-wed';
			break;
		case 4:
			$classes[] = 'start-of-week-thurs';
			break;
		case 5:
			$classes[] = 'start-of-week-fri';
			break;
		case 6:
			$classes[] = 'start-of-week-sat';
	}

	if ( is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'use-widget';
	}

	$current_date_str = date_i18n( 'n:j:w' );
	$new_classes = explode( ':', $current_date_str );

	$new_classes[ 0 ] = 'month' . $new_classes[ 0 ];
	$new_classes[ 1 ] = 'day' . $new_classes[ 1 ];
	$new_classes[ 2 ] = 'week' . $new_classes[ 2 ];

	$classes = array_merge( $classes, $new_classes );

	return $classes;
}
add_filter( 'body_class', 'graftee_body_class' );

function graftee_nav_menu_link_attributes( $atts, $item, $args ) {
	$atts['itemprop']= 'url';

	return $atts;
}
add_filter( 'nav_menu_link_attributes', 'graftee_nav_menu_link_attributes', 10, 3 );

require get_template_directory() . '/theme-options.php';

function graftee_blogname() {
	$output = get_bloginfo( 'name' );

	echo apply_filters( 'graftee_blogname', $output );
}

function graftee_get_header_h1_text() {
	$result = '';

	if ( is_404() ) {
		$result = __( '404 Not Found', 'graftee' );
	} else if ( has_excerpt() ) {
		$result = get_the_excerpt();
	} else if ( is_single() || is_page() ) {
		$result = get_the_title();
	} else if ( is_tag() || is_category() || is_tax() ) {
		$term_description = term_description();
		if ( $term_description != '' ) {
			$result = $term_description;
		} else {
			$result = sprintf( __( "%sに関する記事", 'graftee' ), single_term_title( '', false ) );
		}
	} else if ( is_year() ) {
		$result = get_the_time( __( 'Y年', 'graftee' ) );
	} else if ( is_month() ) {
		$result = get_the_time( __( 'Y年F', 'graftee' ) );
	} else if ( is_day() ) {
		$result = get_the_time( __( 'Y年Fj日', 'graftee' ) );
	} else if ( is_search() ) {
		$result = sprintf( __( "%sに関する記事", 'graftee' ), get_search_query() );
	}

	if ( trim( $result ) == '' ) {
		// is_front_page() || is_home() || other
		$blog_description = get_bloginfo( 'description' );

		if ( $blog_description != '' ) {
			$result = $blog_description;
		} else {
			$result = get_bloginfo( 'name' );
		}
	}

	return strip_tags( $result );
}
function graftee_get_footer_html() {
	$output = '';

	$output .= '<p>';
	$output .= '<small>' . get_bloginfo( 'name' ) . '</small>';
	$output .= '<small role="copyright">' . sprintf( 'Proudly powered by %s and %s', 'WordPress', get_stylesheet() ) . '</small>';
	$output .= '</p>';

	return apply_filters( 'graftee_get_footer_html', $output );
}